import React, { useEffect, useState } from 'react';
import { useParams } from 'react-router';
import CircularProgress from '@material-ui/core/CircularProgress';
import List from '@material-ui/core/List';
import ListItem from '@material-ui/core/ListItem';
import ListItemText from '@material-ui/core/ListItemText';
import Card from '@material-ui/core/Card';
import CardContent from '@material-ui/core/CardContent';
import { useType, useRest } from '../utils/helpers';

const DetailPage = () => {
  const [detail, setDetail] = useState({});
  const [isLoading, setIsLoading] = useState(true);
  const type = useType();
  const [{ resource, rest }] = useRest(type);

  useEffect(() => {
    setIsLoading(true);
    if (resource) {
      resource.get(`rest/${rest}?q={ "_id": "${id}" }`).then(([data]) => {
        setDetail(data);
        setIsLoading(false);
      });
    }
  }, [resource, rest]);
  const { id } = useParams();
  if (isLoading) {
    return (
      <div>
        <CircularProgress />
      </div>
    );
  }
  return (
    <Card>
      <CardContent>
        Detail of {id}:
        {detail ? (
          <List>
            {Object.entries(detail).map(([key, value]) => (
              <ListItem key={key}>
                <ListItemText primary={key} secondary={value} />
              </ListItem>
            ))}
          </List>
        ) : (
          'Error while fetching detail'
        )}
      </CardContent>
    </Card>
  );
};

export default DetailPage;
